@@ -1,7 +1,7 @@
 package Config::IOD::Reader;
 
-our $DATE = '2017-08-05'; # DATE
-our $VERSION = '0.33'; # VERSION
+our $DATE = '2018-04-04'; # DATE
+our $VERSION = '0.340'; # VERSION
 
 use 5.010001;
 use strict;
@@ -109,7 +109,7 @@ sub _read_string {
                     $self->_err("Can't include '$path': $res->[1]");
                 }
                 $path = $res->[2];
-                $self->_read_string($self->_read_file($path, $cb));
+                $self->_read_string($self->_read_file($path, $cb), $cb);
                 $self->_pop_include_stack;
             } elsif ($directive eq 'merge') {
                 $self->{_merge} = @$args ? $args : undef;
@@ -230,7 +230,7 @@ Config::IOD::Reader - Read IOD/INI configuration files
 
 =head1 VERSION
 
-This document describes version 0.33 of Config::IOD::Reader (from Perl distribution Config-IOD-Reader), released on 2017-08-05.
+This document describes version 0.340 of Config::IOD::Reader (from Perl distribution Config-IOD-Reader), released on 2018-04-04.
 
 =head1 SYNOPSIS
 
@@ -536,7 +536,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
